@@ -44,6 +44,9 @@ Usage::
         DescribeInstanceTypesPaginator,
         DescribeInstancesPaginator,
         DescribeInternetGatewaysPaginator,
+        DescribeIpamPoolsPaginator,
+        DescribeIpamScopesPaginator,
+        DescribeIpamsPaginator,
         DescribeIpv6PoolsPaginator,
         DescribeLaunchTemplateVersionsPaginator,
         DescribeLaunchTemplatesPaginator,
@@ -57,6 +60,8 @@ Usage::
         DescribeMovingAddressesPaginator,
         DescribeNatGatewaysPaginator,
         DescribeNetworkAclsPaginator,
+        DescribeNetworkInsightsAccessScopeAnalysesPaginator,
+        DescribeNetworkInsightsAccessScopesPaginator,
         DescribeNetworkInsightsAnalysesPaginator,
         DescribeNetworkInsightsPathsPaginator,
         DescribeNetworkInterfacePermissionsPaginator,
@@ -113,6 +118,10 @@ Usage::
         GetAssociatedIpv6PoolCidrsPaginator,
         GetGroupsForCapacityReservationPaginator,
         GetInstanceTypesFromInstanceRequirementsPaginator,
+        GetIpamAddressHistoryPaginator,
+        GetIpamPoolAllocationsPaginator,
+        GetIpamPoolCidrsPaginator,
+        GetIpamResourceCidrsPaginator,
         GetManagedPrefixListAssociationsPaginator,
         GetManagedPrefixListEntriesPaginator,
         GetSpotPlacementScoresPaginator,
@@ -129,6 +138,7 @@ Usage::
         InstanceStatusOkWaiter,
         InstanceStoppedWaiter,
         InstanceTerminatedWaiter,
+        InternetGatewayExistsWaiter,
         KeyPairExistsWaiter,
         ListSnapshotsInRecycleBinPaginator,
         NatGatewayAvailableWaiter,
@@ -175,6 +185,7 @@ Usage::
     instance_status_ok_waiter: InstanceStatusOkWaiter = client.get_waiter("instance_status_ok")
     instance_stopped_waiter: InstanceStoppedWaiter = client.get_waiter("instance_stopped")
     instance_terminated_waiter: InstanceTerminatedWaiter = client.get_waiter("instance_terminated")
+    internet_gateway_exists_waiter: InternetGatewayExistsWaiter = client.get_waiter("internet_gateway_exists")
     key_pair_exists_waiter: KeyPairExistsWaiter = client.get_waiter("key_pair_exists")
     nat_gateway_available_waiter: NatGatewayAvailableWaiter = client.get_waiter("nat_gateway_available")
     network_interface_available_waiter: NetworkInterfaceAvailableWaiter = client.get_waiter("network_interface_available")
@@ -226,6 +237,9 @@ Usage::
     describe_instance_types_paginator: DescribeInstanceTypesPaginator = client.get_paginator("describe_instance_types")
     describe_instances_paginator: DescribeInstancesPaginator = client.get_paginator("describe_instances")
     describe_internet_gateways_paginator: DescribeInternetGatewaysPaginator = client.get_paginator("describe_internet_gateways")
+    describe_ipam_pools_paginator: DescribeIpamPoolsPaginator = client.get_paginator("describe_ipam_pools")
+    describe_ipam_scopes_paginator: DescribeIpamScopesPaginator = client.get_paginator("describe_ipam_scopes")
+    describe_ipams_paginator: DescribeIpamsPaginator = client.get_paginator("describe_ipams")
     describe_ipv6_pools_paginator: DescribeIpv6PoolsPaginator = client.get_paginator("describe_ipv6_pools")
     describe_launch_template_versions_paginator: DescribeLaunchTemplateVersionsPaginator = client.get_paginator("describe_launch_template_versions")
     describe_launch_templates_paginator: DescribeLaunchTemplatesPaginator = client.get_paginator("describe_launch_templates")
@@ -239,6 +253,8 @@ Usage::
     describe_moving_addresses_paginator: DescribeMovingAddressesPaginator = client.get_paginator("describe_moving_addresses")
     describe_nat_gateways_paginator: DescribeNatGatewaysPaginator = client.get_paginator("describe_nat_gateways")
     describe_network_acls_paginator: DescribeNetworkAclsPaginator = client.get_paginator("describe_network_acls")
+    describe_network_insights_access_scope_analyses_paginator: DescribeNetworkInsightsAccessScopeAnalysesPaginator = client.get_paginator("describe_network_insights_access_scope_analyses")
+    describe_network_insights_access_scopes_paginator: DescribeNetworkInsightsAccessScopesPaginator = client.get_paginator("describe_network_insights_access_scopes")
     describe_network_insights_analyses_paginator: DescribeNetworkInsightsAnalysesPaginator = client.get_paginator("describe_network_insights_analyses")
     describe_network_insights_paths_paginator: DescribeNetworkInsightsPathsPaginator = client.get_paginator("describe_network_insights_paths")
     describe_network_interface_permissions_paginator: DescribeNetworkInterfacePermissionsPaginator = client.get_paginator("describe_network_interface_permissions")
@@ -291,6 +307,10 @@ Usage::
     get_associated_ipv6_pool_cidrs_paginator: GetAssociatedIpv6PoolCidrsPaginator = client.get_paginator("get_associated_ipv6_pool_cidrs")
     get_groups_for_capacity_reservation_paginator: GetGroupsForCapacityReservationPaginator = client.get_paginator("get_groups_for_capacity_reservation")
     get_instance_types_from_instance_requirements_paginator: GetInstanceTypesFromInstanceRequirementsPaginator = client.get_paginator("get_instance_types_from_instance_requirements")
+    get_ipam_address_history_paginator: GetIpamAddressHistoryPaginator = client.get_paginator("get_ipam_address_history")
+    get_ipam_pool_allocations_paginator: GetIpamPoolAllocationsPaginator = client.get_paginator("get_ipam_pool_allocations")
+    get_ipam_pool_cidrs_paginator: GetIpamPoolCidrsPaginator = client.get_paginator("get_ipam_pool_cidrs")
+    get_ipam_resource_cidrs_paginator: GetIpamResourceCidrsPaginator = client.get_paginator("get_ipam_resource_cidrs")
     get_managed_prefix_list_associations_paginator: GetManagedPrefixListAssociationsPaginator = client.get_paginator("get_managed_prefix_list_associations")
     get_managed_prefix_list_entries_paginator: GetManagedPrefixListEntriesPaginator = client.get_paginator("get_managed_prefix_list_entries")
     get_spot_placement_scores_paginator: GetSpotPlacementScoresPaginator = client.get_paginator("get_spot_placement_scores")
@@ -339,6 +359,9 @@ from .paginator import (
     DescribeInstanceTypeOfferingsPaginator,
     DescribeInstanceTypesPaginator,
     DescribeInternetGatewaysPaginator,
+    DescribeIpamPoolsPaginator,
+    DescribeIpamScopesPaginator,
+    DescribeIpamsPaginator,
     DescribeIpv6PoolsPaginator,
     DescribeLaunchTemplatesPaginator,
     DescribeLaunchTemplateVersionsPaginator,
@@ -352,6 +375,8 @@ from .paginator import (
     DescribeMovingAddressesPaginator,
     DescribeNatGatewaysPaginator,
     DescribeNetworkAclsPaginator,
+    DescribeNetworkInsightsAccessScopeAnalysesPaginator,
+    DescribeNetworkInsightsAccessScopesPaginator,
     DescribeNetworkInsightsAnalysesPaginator,
     DescribeNetworkInsightsPathsPaginator,
     DescribeNetworkInterfacePermissionsPaginator,
@@ -404,6 +429,10 @@ from .paginator import (
     GetAssociatedIpv6PoolCidrsPaginator,
     GetGroupsForCapacityReservationPaginator,
     GetInstanceTypesFromInstanceRequirementsPaginator,
+    GetIpamAddressHistoryPaginator,
+    GetIpamPoolAllocationsPaginator,
+    GetIpamPoolCidrsPaginator,
+    GetIpamResourceCidrsPaginator,
     GetManagedPrefixListAssociationsPaginator,
     GetManagedPrefixListEntriesPaginator,
     GetSpotPlacementScoresPaginator,
@@ -433,6 +462,7 @@ from .waiter import (
     InstanceStatusOkWaiter,
     InstanceStoppedWaiter,
     InstanceTerminatedWaiter,
+    InternetGatewayExistsWaiter,
     KeyPairExistsWaiter,
     NatGatewayAvailableWaiter,
     NetworkInterfaceAvailableWaiter,
@@ -498,6 +528,9 @@ __all__ = (
     "DescribeInstanceTypesPaginator",
     "DescribeInstancesPaginator",
     "DescribeInternetGatewaysPaginator",
+    "DescribeIpamPoolsPaginator",
+    "DescribeIpamScopesPaginator",
+    "DescribeIpamsPaginator",
     "DescribeIpv6PoolsPaginator",
     "DescribeLaunchTemplateVersionsPaginator",
     "DescribeLaunchTemplatesPaginator",
@@ -511,6 +544,8 @@ __all__ = (
     "DescribeMovingAddressesPaginator",
     "DescribeNatGatewaysPaginator",
     "DescribeNetworkAclsPaginator",
+    "DescribeNetworkInsightsAccessScopeAnalysesPaginator",
+    "DescribeNetworkInsightsAccessScopesPaginator",
     "DescribeNetworkInsightsAnalysesPaginator",
     "DescribeNetworkInsightsPathsPaginator",
     "DescribeNetworkInterfacePermissionsPaginator",
@@ -567,6 +602,10 @@ __all__ = (
     "GetAssociatedIpv6PoolCidrsPaginator",
     "GetGroupsForCapacityReservationPaginator",
     "GetInstanceTypesFromInstanceRequirementsPaginator",
+    "GetIpamAddressHistoryPaginator",
+    "GetIpamPoolAllocationsPaginator",
+    "GetIpamPoolCidrsPaginator",
+    "GetIpamResourceCidrsPaginator",
     "GetManagedPrefixListAssociationsPaginator",
     "GetManagedPrefixListEntriesPaginator",
     "GetSpotPlacementScoresPaginator",
@@ -583,6 +622,7 @@ __all__ = (
     "InstanceStatusOkWaiter",
     "InstanceStoppedWaiter",
     "InstanceTerminatedWaiter",
+    "InternetGatewayExistsWaiter",
     "KeyPairExistsWaiter",
     "ListSnapshotsInRecycleBinPaginator",
     "NatGatewayAvailableWaiter",
