@@ -26,6 +26,7 @@ __all__ = (
     "AccountAttributeNameType",
     "ActivityStatusType",
     "AddressAttributeNameType",
+    "AddressFamilyType",
     "AffinityType",
     "AllocationStateType",
     "AllocationStrategyType",
@@ -116,6 +117,9 @@ __all__ = (
     "DescribeInstanceTypesPaginatorName",
     "DescribeInstancesPaginatorName",
     "DescribeInternetGatewaysPaginatorName",
+    "DescribeIpamPoolsPaginatorName",
+    "DescribeIpamScopesPaginatorName",
+    "DescribeIpamsPaginatorName",
     "DescribeIpv6PoolsPaginatorName",
     "DescribeLaunchTemplateVersionsPaginatorName",
     "DescribeLaunchTemplatesPaginatorName",
@@ -129,6 +133,8 @@ __all__ = (
     "DescribeMovingAddressesPaginatorName",
     "DescribeNatGatewaysPaginatorName",
     "DescribeNetworkAclsPaginatorName",
+    "DescribeNetworkInsightsAccessScopeAnalysesPaginatorName",
+    "DescribeNetworkInsightsAccessScopesPaginatorName",
     "DescribeNetworkInsightsAnalysesPaginatorName",
     "DescribeNetworkInsightsPathsPaginatorName",
     "DescribeNetworkInterfacePermissionsPaginatorName",
@@ -201,6 +207,7 @@ __all__ = (
     "ExportTaskCompletedWaiterName",
     "ExportTaskStateType",
     "FastSnapshotRestoreStateCodeType",
+    "FindingsFoundType",
     "FleetActivityStatusType",
     "FleetCapacityReservationTenancyType",
     "FleetCapacityReservationUsageStrategyType",
@@ -219,6 +226,10 @@ __all__ = (
     "GetAssociatedIpv6PoolCidrsPaginatorName",
     "GetGroupsForCapacityReservationPaginatorName",
     "GetInstanceTypesFromInstanceRequirementsPaginatorName",
+    "GetIpamAddressHistoryPaginatorName",
+    "GetIpamPoolAllocationsPaginatorName",
+    "GetIpamPoolCidrsPaginatorName",
+    "GetIpamResourceCidrsPaginatorName",
     "GetManagedPrefixListAssociationsPaginatorName",
     "GetManagedPrefixListEntriesPaginatorName",
     "GetSpotPlacementScoresPaginatorName",
@@ -262,6 +273,20 @@ __all__ = (
     "InstanceTypeType",
     "InterfacePermissionTypeType",
     "InterfaceProtocolTypeType",
+    "InternetGatewayExistsWaiterName",
+    "IpamAddressHistoryResourceTypeType",
+    "IpamComplianceStatusType",
+    "IpamManagementStateType",
+    "IpamOverlapStatusType",
+    "IpamPoolAllocationResourceTypeType",
+    "IpamPoolAwsServiceType",
+    "IpamPoolCidrFailureCodeType",
+    "IpamPoolCidrStateType",
+    "IpamPoolStateType",
+    "IpamResourceTypeType",
+    "IpamScopeStateType",
+    "IpamScopeTypeType",
+    "IpamStateType",
     "Ipv6SupportValueType",
     "KeyPairExistsWaiterName",
     "KeyTypeType",
@@ -423,6 +448,7 @@ AcceleratorTypeType = Literal["fpga", "gpu", "inference"]
 AccountAttributeNameType = Literal["default-vpc", "supported-platforms"]
 ActivityStatusType = Literal["error", "fulfilled", "pending_fulfillment", "pending_termination"]
 AddressAttributeNameType = Literal["domain-name"]
+AddressFamilyType = Literal["ipv4", "ipv6"]
 AffinityType = Literal["default", "host"]
 AllocationStateType = Literal[
     "available",
@@ -584,6 +610,9 @@ DescribeInstanceTypeOfferingsPaginatorName = Literal["describe_instance_type_off
 DescribeInstanceTypesPaginatorName = Literal["describe_instance_types"]
 DescribeInstancesPaginatorName = Literal["describe_instances"]
 DescribeInternetGatewaysPaginatorName = Literal["describe_internet_gateways"]
+DescribeIpamPoolsPaginatorName = Literal["describe_ipam_pools"]
+DescribeIpamScopesPaginatorName = Literal["describe_ipam_scopes"]
+DescribeIpamsPaginatorName = Literal["describe_ipams"]
 DescribeIpv6PoolsPaginatorName = Literal["describe_ipv6_pools"]
 DescribeLaunchTemplateVersionsPaginatorName = Literal["describe_launch_template_versions"]
 DescribeLaunchTemplatesPaginatorName = Literal["describe_launch_templates"]
@@ -605,6 +634,12 @@ DescribeManagedPrefixListsPaginatorName = Literal["describe_managed_prefix_lists
 DescribeMovingAddressesPaginatorName = Literal["describe_moving_addresses"]
 DescribeNatGatewaysPaginatorName = Literal["describe_nat_gateways"]
 DescribeNetworkAclsPaginatorName = Literal["describe_network_acls"]
+DescribeNetworkInsightsAccessScopeAnalysesPaginatorName = Literal[
+    "describe_network_insights_access_scope_analyses"
+]
+DescribeNetworkInsightsAccessScopesPaginatorName = Literal[
+    "describe_network_insights_access_scopes"
+]
 DescribeNetworkInsightsAnalysesPaginatorName = Literal["describe_network_insights_analyses"]
 DescribeNetworkInsightsPathsPaginatorName = Literal["describe_network_insights_paths"]
 DescribeNetworkInterfacePermissionsPaginatorName = Literal["describe_network_interface_permissions"]
@@ -697,6 +732,7 @@ ExportTaskStateType = Literal["active", "cancelled", "cancelling", "completed"]
 FastSnapshotRestoreStateCodeType = Literal[
     "disabled", "disabling", "enabled", "enabling", "optimizing"
 ]
+FindingsFoundType = Literal["false", "true", "unknown"]
 FleetActivityStatusType = Literal[
     "error", "fulfilled", "pending_fulfillment", "pending_termination"
 ]
@@ -729,6 +765,10 @@ GetGroupsForCapacityReservationPaginatorName = Literal["get_groups_for_capacity_
 GetInstanceTypesFromInstanceRequirementsPaginatorName = Literal[
     "get_instance_types_from_instance_requirements"
 ]
+GetIpamAddressHistoryPaginatorName = Literal["get_ipam_address_history"]
+GetIpamPoolAllocationsPaginatorName = Literal["get_ipam_pool_allocations"]
+GetIpamPoolCidrsPaginatorName = Literal["get_ipam_pool_cidrs"]
+GetIpamResourceCidrsPaginatorName = Literal["get_ipam_resource_cidrs"]
 GetManagedPrefixListAssociationsPaginatorName = Literal["get_managed_prefix_list_associations"]
 GetManagedPrefixListEntriesPaginatorName = Literal["get_managed_prefix_list_entries"]
 GetSpotPlacementScoresPaginatorName = Literal["get_spot_placement_scores"]
@@ -1280,6 +1320,61 @@ InstanceTypeType = Literal[
 ]
 InterfacePermissionTypeType = Literal["EIP-ASSOCIATE", "INSTANCE-ATTACH"]
 InterfaceProtocolTypeType = Literal["GRE", "VLAN"]
+InternetGatewayExistsWaiterName = Literal["internet_gateway_exists"]
+IpamAddressHistoryResourceTypeType = Literal[
+    "eip", "instance", "network-interface", "subnet", "vpc"
+]
+IpamComplianceStatusType = Literal["compliant", "ignored", "noncompliant", "unmanaged"]
+IpamManagementStateType = Literal["ignored", "managed", "unmanaged"]
+IpamOverlapStatusType = Literal["ignored", "nonoverlapping", "overlapping"]
+IpamPoolAllocationResourceTypeType = Literal["custom", "ec2-public-ipv4-pool", "ipam-pool", "vpc"]
+IpamPoolAwsServiceType = Literal["ec2"]
+IpamPoolCidrFailureCodeType = Literal["cidr-not-available"]
+IpamPoolCidrStateType = Literal[
+    "deprovisioned",
+    "failed-deprovision",
+    "failed-import",
+    "failed-provision",
+    "pending-deprovision",
+    "pending-import",
+    "pending-provision",
+    "provisioned",
+]
+IpamPoolStateType = Literal[
+    "create-complete",
+    "create-failed",
+    "create-in-progress",
+    "delete-complete",
+    "delete-failed",
+    "delete-in-progress",
+    "modify-complete",
+    "modify-failed",
+    "modify-in-progress",
+]
+IpamResourceTypeType = Literal["eip", "ipv6-pool", "public-ipv4-pool", "subnet", "vpc"]
+IpamScopeStateType = Literal[
+    "create-complete",
+    "create-failed",
+    "create-in-progress",
+    "delete-complete",
+    "delete-failed",
+    "delete-in-progress",
+    "modify-complete",
+    "modify-failed",
+    "modify-in-progress",
+]
+IpamScopeTypeType = Literal["private", "public"]
+IpamStateType = Literal[
+    "create-complete",
+    "create-failed",
+    "create-in-progress",
+    "delete-complete",
+    "delete-failed",
+    "delete-in-progress",
+    "modify-complete",
+    "modify-failed",
+    "modify-in-progress",
+]
 Ipv6SupportValueType = Literal["disable", "enable"]
 KeyPairExistsWaiterName = Literal["key_pair_exists"]
 KeyTypeType = Literal["ed25519", "rsa"]
@@ -1402,6 +1497,9 @@ ResourceTypeType = Literal[
     "instance",
     "instance-event-window",
     "internet-gateway",
+    "ipam",
+    "ipam-pool",
+    "ipam-scope",
     "ipv4pool-ec2",
     "ipv6pool-ec2",
     "key-pair",
@@ -1414,6 +1512,8 @@ ResourceTypeType = Literal[
     "local-gateway-virtual-interface-group",
     "natgateway",
     "network-acl",
+    "network-insights-access-scope",
+    "network-insights-access-scope-analysis",
     "network-insights-analysis",
     "network-insights-path",
     "network-interface",
@@ -1618,6 +1718,7 @@ ServiceName = Literal[
     "amp",
     "amplify",
     "amplifybackend",
+    "amplifyuibuilder",
     "apigateway",
     "apigatewaymanagementapi",
     "apigatewayv2",
@@ -1942,6 +2043,9 @@ PaginatorName = Literal[
     "describe_instance_types",
     "describe_instances",
     "describe_internet_gateways",
+    "describe_ipam_pools",
+    "describe_ipam_scopes",
+    "describe_ipams",
     "describe_ipv6_pools",
     "describe_launch_template_versions",
     "describe_launch_templates",
@@ -1955,6 +2059,8 @@ PaginatorName = Literal[
     "describe_moving_addresses",
     "describe_nat_gateways",
     "describe_network_acls",
+    "describe_network_insights_access_scope_analyses",
+    "describe_network_insights_access_scopes",
     "describe_network_insights_analyses",
     "describe_network_insights_paths",
     "describe_network_interface_permissions",
@@ -2007,6 +2113,10 @@ PaginatorName = Literal[
     "get_associated_ipv6_pool_cidrs",
     "get_groups_for_capacity_reservation",
     "get_instance_types_from_instance_requirements",
+    "get_ipam_address_history",
+    "get_ipam_pool_allocations",
+    "get_ipam_pool_cidrs",
+    "get_ipam_resource_cidrs",
     "get_managed_prefix_list_associations",
     "get_managed_prefix_list_entries",
     "get_spot_placement_scores",
@@ -2035,6 +2145,7 @@ WaiterName = Literal[
     "instance_status_ok",
     "instance_stopped",
     "instance_terminated",
+    "internet_gateway_exists",
     "key_pair_exists",
     "nat_gateway_available",
     "network_interface_available",
