@@ -24,6 +24,7 @@ Usage::
         InstanceStatusOkWaiter,
         InstanceStoppedWaiter,
         InstanceTerminatedWaiter,
+        InternetGatewayExistsWaiter,
         KeyPairExistsWaiter,
         NatGatewayAvailableWaiter,
         NetworkInterfaceAvailableWaiter,
@@ -60,6 +61,7 @@ Usage::
     instance_status_ok_waiter: InstanceStatusOkWaiter = client.get_waiter("instance_status_ok")
     instance_stopped_waiter: InstanceStoppedWaiter = client.get_waiter("instance_stopped")
     instance_terminated_waiter: InstanceTerminatedWaiter = client.get_waiter("instance_terminated")
+    internet_gateway_exists_waiter: InternetGatewayExistsWaiter = client.get_waiter("internet_gateway_exists")
     key_pair_exists_waiter: KeyPairExistsWaiter = client.get_waiter("key_pair_exists")
     nat_gateway_available_waiter: NatGatewayAvailableWaiter = client.get_waiter("nat_gateway_available")
     network_interface_available_waiter: NetworkInterfaceAvailableWaiter = client.get_waiter("network_interface_available")
@@ -101,6 +103,7 @@ __all__ = (
     "InstanceStatusOkWaiter",
     "InstanceStoppedWaiter",
     "InstanceTerminatedWaiter",
+    "InternetGatewayExistsWaiter",
     "KeyPairExistsWaiter",
     "NatGatewayAvailableWaiter",
     "NetworkInterfaceAvailableWaiter",
@@ -124,7 +127,7 @@ __all__ = (
 
 class BundleTaskCompleteWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.BundleTaskComplete)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.BundleTaskComplete)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#bundletaskcompletewaiter)
     """
 
@@ -137,14 +140,14 @@ class BundleTaskCompleteWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.BundleTaskComplete.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.BundleTaskComplete.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#bundletaskcompletewaiter)
         """
 
 
 class ConversionTaskCancelledWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ConversionTaskCancelled)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ConversionTaskCancelled)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#conversiontaskcancelledwaiter)
     """
 
@@ -156,14 +159,14 @@ class ConversionTaskCancelledWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ConversionTaskCancelled.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ConversionTaskCancelled.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#conversiontaskcancelledwaiter)
         """
 
 
 class ConversionTaskCompletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ConversionTaskCompleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ConversionTaskCompleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#conversiontaskcompletedwaiter)
     """
 
@@ -175,14 +178,14 @@ class ConversionTaskCompletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ConversionTaskCompleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ConversionTaskCompleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#conversiontaskcompletedwaiter)
         """
 
 
 class ConversionTaskDeletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ConversionTaskDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ConversionTaskDeleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#conversiontaskdeletedwaiter)
     """
 
@@ -194,14 +197,14 @@ class ConversionTaskDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ConversionTaskDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ConversionTaskDeleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#conversiontaskdeletedwaiter)
         """
 
 
 class CustomerGatewayAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.CustomerGatewayAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.CustomerGatewayAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#customergatewayavailablewaiter)
     """
 
@@ -214,14 +217,14 @@ class CustomerGatewayAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.CustomerGatewayAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.CustomerGatewayAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#customergatewayavailablewaiter)
         """
 
 
 class ExportTaskCancelledWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ExportTaskCancelled)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ExportTaskCancelled)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#exporttaskcancelledwaiter)
     """
 
@@ -233,14 +236,14 @@ class ExportTaskCancelledWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ExportTaskCancelled.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ExportTaskCancelled.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#exporttaskcancelledwaiter)
         """
 
 
 class ExportTaskCompletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ExportTaskCompleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ExportTaskCompleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#exporttaskcompletedwaiter)
     """
 
@@ -252,14 +255,14 @@ class ExportTaskCompletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ExportTaskCompleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ExportTaskCompleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#exporttaskcompletedwaiter)
         """
 
 
 class ImageAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ImageAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ImageAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#imageavailablewaiter)
     """
 
@@ -275,14 +278,14 @@ class ImageAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ImageAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ImageAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#imageavailablewaiter)
         """
 
 
 class ImageExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ImageExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ImageExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#imageexistswaiter)
     """
 
@@ -298,14 +301,14 @@ class ImageExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.ImageExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.ImageExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#imageexistswaiter)
         """
 
 
 class InstanceExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instanceexistswaiter)
     """
 
@@ -320,14 +323,14 @@ class InstanceExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instanceexistswaiter)
         """
 
 
 class InstanceRunningWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceRunning)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceRunning)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instancerunningwaiter)
     """
 
@@ -342,14 +345,14 @@ class InstanceRunningWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceRunning.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceRunning.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instancerunningwaiter)
         """
 
 
 class InstanceStatusOkWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceStatusOk)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceStatusOk)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instancestatusokwaiter)
     """
 
@@ -365,14 +368,14 @@ class InstanceStatusOkWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceStatusOk.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceStatusOk.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instancestatusokwaiter)
         """
 
 
 class InstanceStoppedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceStopped)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceStopped)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instancestoppedwaiter)
     """
 
@@ -387,14 +390,14 @@ class InstanceStoppedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceStopped.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceStopped.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instancestoppedwaiter)
         """
 
 
 class InstanceTerminatedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceTerminated)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceTerminated)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instanceterminatedwaiter)
     """
 
@@ -409,14 +412,36 @@ class InstanceTerminatedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.InstanceTerminated.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InstanceTerminated.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#instanceterminatedwaiter)
         """
 
 
+class InternetGatewayExistsWaiter(Boto3Waiter):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InternetGatewayExists)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#internetgatewayexistswaiter)
+    """
+
+    def wait(
+        self,
+        *,
+        Filters: Sequence["FilterTypeDef"] = ...,
+        DryRun: bool = ...,
+        InternetGatewayIds: Sequence[str] = ...,
+        NextToken: str = ...,
+        MaxResults: int = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
+    ) -> None:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.InternetGatewayExists.wait)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#internetgatewayexistswaiter)
+        """
+
+
 class KeyPairExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.KeyPairExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.KeyPairExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#keypairexistswaiter)
     """
 
@@ -430,14 +455,14 @@ class KeyPairExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.KeyPairExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.KeyPairExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#keypairexistswaiter)
         """
 
 
 class NatGatewayAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.NatGatewayAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.NatGatewayAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#natgatewayavailablewaiter)
     """
 
@@ -452,14 +477,14 @@ class NatGatewayAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.NatGatewayAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.NatGatewayAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#natgatewayavailablewaiter)
         """
 
 
 class NetworkInterfaceAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#networkinterfaceavailablewaiter)
     """
 
@@ -474,14 +499,14 @@ class NetworkInterfaceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.NetworkInterfaceAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#networkinterfaceavailablewaiter)
         """
 
 
 class PasswordDataAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.PasswordDataAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.PasswordDataAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#passworddataavailablewaiter)
     """
 
@@ -489,14 +514,14 @@ class PasswordDataAvailableWaiter(Boto3Waiter):
         self, *, InstanceId: str, DryRun: bool = ..., WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.PasswordDataAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.PasswordDataAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#passworddataavailablewaiter)
         """
 
 
 class SecurityGroupExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SecurityGroupExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SecurityGroupExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#securitygroupexistswaiter)
     """
 
@@ -512,14 +537,14 @@ class SecurityGroupExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SecurityGroupExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SecurityGroupExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#securitygroupexistswaiter)
         """
 
 
 class SnapshotCompletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SnapshotCompleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SnapshotCompleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#snapshotcompletedwaiter)
     """
 
@@ -536,14 +561,14 @@ class SnapshotCompletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SnapshotCompleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SnapshotCompleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#snapshotcompletedwaiter)
         """
 
 
 class SpotInstanceRequestFulfilledWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#spotinstancerequestfulfilledwaiter)
     """
 
@@ -558,14 +583,14 @@ class SpotInstanceRequestFulfilledWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SpotInstanceRequestFulfilled.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#spotinstancerequestfulfilledwaiter)
         """
 
 
 class SubnetAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SubnetAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SubnetAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#subnetavailablewaiter)
     """
 
@@ -580,14 +605,14 @@ class SubnetAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SubnetAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SubnetAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#subnetavailablewaiter)
         """
 
 
 class SystemStatusOkWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SystemStatusOk)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SystemStatusOk)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#systemstatusokwaiter)
     """
 
@@ -603,14 +628,14 @@ class SystemStatusOkWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.SystemStatusOk.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.SystemStatusOk.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#systemstatusokwaiter)
         """
 
 
 class VolumeAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VolumeAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VolumeAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#volumeavailablewaiter)
     """
 
@@ -625,14 +650,14 @@ class VolumeAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VolumeAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VolumeAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#volumeavailablewaiter)
         """
 
 
 class VolumeDeletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VolumeDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VolumeDeleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#volumedeletedwaiter)
     """
 
@@ -647,14 +672,14 @@ class VolumeDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VolumeDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VolumeDeleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#volumedeletedwaiter)
         """
 
 
 class VolumeInUseWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VolumeInUse)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VolumeInUse)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#volumeinusewaiter)
     """
 
@@ -669,14 +694,14 @@ class VolumeInUseWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VolumeInUse.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VolumeInUse.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#volumeinusewaiter)
         """
 
 
 class VpcAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcavailablewaiter)
     """
 
@@ -691,14 +716,14 @@ class VpcAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcavailablewaiter)
         """
 
 
 class VpcExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcexistswaiter)
     """
 
@@ -713,14 +738,14 @@ class VpcExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcexistswaiter)
         """
 
 
 class VpcPeeringConnectionDeletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionDeleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcpeeringconnectiondeletedwaiter)
     """
 
@@ -735,14 +760,14 @@ class VpcPeeringConnectionDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionDeleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcpeeringconnectiondeletedwaiter)
         """
 
 
 class VpcPeeringConnectionExistsWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionExists)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionExists)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcpeeringconnectionexistswaiter)
     """
 
@@ -757,14 +782,14 @@ class VpcPeeringConnectionExistsWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionExists.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpcPeeringConnectionExists.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpcpeeringconnectionexistswaiter)
         """
 
 
 class VpnConnectionAvailableWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpnConnectionAvailable)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpnConnectionAvailable)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpnconnectionavailablewaiter)
     """
 
@@ -777,14 +802,14 @@ class VpnConnectionAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpnConnectionAvailable.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpnConnectionAvailable.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpnconnectionavailablewaiter)
         """
 
 
 class VpnConnectionDeletedWaiter(Boto3Waiter):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpnConnectionDeleted)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpnConnectionDeleted)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpnconnectiondeletedwaiter)
     """
 
@@ -797,6 +822,6 @@ class VpnConnectionDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.17/reference/services/ec2.html#EC2.Waiter.VpnConnectionDeleted.wait)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.23/reference/services/ec2.html#EC2.Waiter.VpnConnectionDeleted.wait)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ec2/waiters.html#vpnconnectiondeletedwaiter)
         """
